@@ -36,7 +36,6 @@ std::optional<float>                    getPlusMinusKeywordResult(std::string in
 double                                  normalizeAngleRad(double ang);
 std::vector<SCallstackFrameInfo>        getBacktrace();
 void                                    throwError(const std::string& err);
-bool                                    envEnabled(const std::string& env);
 Hyprutils::OS::CFileDescriptor          allocateSHMFile(size_t len);
 bool                                    allocateSHMFilePair(size_t size, Hyprutils::OS::CFileDescriptor& rw_fd_ptr, Hyprutils::OS::CFileDescriptor& ro_fd_ptr);
 float                                   stringToPercentage(const std::string& VALUE, const float REL);
@@ -46,6 +45,7 @@ std::expected<std::string, std::string> binaryNameForPid(pid_t pid);
 std::string                             deviceNameToInternalString(std::string in);
 std::string                             getSystemLibraryVersion(const std::string& name);
 std::string                             getBuiltSystemLibraryNames();
+bool                                    truthy(const std::string& str);
 
 template <typename... Args>
 [[deprecated("use std::format instead")]] std::string getFormat(std::format_string<Args...> fmt, Args&&... args) {
